@@ -1,7 +1,5 @@
-/* $Id: lex.c,v 1.30 2008/01/30 12:06:50 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2008 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -58,6 +56,7 @@
 #include "xmalloc.h"
 #include "lex.h"
 #include "error.h"
+#include "sylimits.h"
 
 static struct {
     const char *name;
@@ -75,6 +74,7 @@ static struct {
     { "debug", LXT_DEBUG },
     { "df", LXT_DF },
     { "every", LXT_EVERY },
+    { "flukso", LXT_FLUKSO },
     { "from", LXT_FROM },
     { "if", LXT_IF },
     { "if1", LXT_IF1 },
@@ -83,6 +83,7 @@ static struct {
     { "io", LXT_IO },
     { "io1", LXT_IO1 },
     { "io2", LXT_IO },
+    { "load", LXT_LOAD },
     { "mbuf", LXT_MBUF },
     { "mem", LXT_MEM },
     { "mem1", LXT_MEM1 },
@@ -96,6 +97,7 @@ static struct {
     { "second", LXT_SECOND },
     { "seconds", LXT_SECONDS },
     { "sensor", LXT_SENSOR },
+    { "smart", LXT_SMART },
     { "source", LXT_SOURCE },
     { "stream", LXT_STREAM },
     { "to", LXT_TO },
@@ -171,14 +173,16 @@ lex_copychar(struct lex *l)
 int
 lex_nextchar(struct lex *l)
 {
-    if (l == NULL)
+    if (l == NULL || l->eof)
         return 0;
 
     l->curpos++;
 
     if (l->curpos >= l->endpos)
-        if (!lex_readline(l))
+        if (!lex_readline(l)) {
+            l->eof = 1;
             return 0;
+        }
 
     if (l->buffer[l->curpos] == '\n')
         l->cline++;
@@ -208,7 +212,7 @@ lex_ungettoken(struct lex *l)
 int
 lex_nexttoken(struct lex *l)
 {
-    if (l == NULL)
+    if (l == NULL || l->eof)
         return 0;
 
     /* return same token as last time if it has been pushed back */
@@ -304,6 +308,9 @@ lex_nexttoken(struct lex *l)
         if (strlen(l->token) == strspn(l->token, "0123456789")) {
             l->type = LXY_NUMBER;
             l->value = strtol(l->token, NULL, 10);
+            if (l->value > SYMON_MAXLEXNUM) {
+                fatal("%.200s:%d: parse error at '%.200s': number too large", l->filename, l->cline, l->token);
+            }
         }
     }
     return 1;
@@ -360,6 +367,7 @@ reset_lex(struct lex *l)
     l->tokpos = 0;
     l->type = LXY_UNKNOWN;
     l->unget = 0;
+    l->eof = 0;
     l->value = 0;
 }
 /* Destroy a lexical analyser */
