@@ -1,8 +1,6 @@
-/* $Id: sm_if.c,v 1.5 2007/12/11 14:17:59 dijkstra Exp $ */
-
 /*
  * Copyright (c) 2005 Fredrik Soderblom
- * Copyright (c) 2005-2007 Willem Dijkstra
+ * Copyright (c) 2005-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -94,7 +92,7 @@ get_ifmib_general(int row, struct ifmibdata *ifmd)
 }
 
 void
-gets_if()
+gets_if(void)
 {
     int i;
 
