@@ -10,4 +10,10 @@ if [ -f /proc/partitions ]; then
     else
 	echo "#undef HAS_PROC_PARTITIONS"
     fi
-fi
\ No newline at end of file
+fi
+if grep -q "hd_drive_cmd_hdr" /usr/include/linux/hdreg.h; then
+    echo "#define HAS_HDDRIVECMDHDR 1"
+else
+    echo "#undef HAS_HDDRIVECMDHDR"
+fi
+
