@@ -1,7 +1,5 @@
-/* $Id: sm_if.c,v 1.9 2007/12/11 18:31:37 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2007 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,15 +35,17 @@
  * oerrors : colls : drops
  */
 
+#include "conf.h"
+
 #include <sys/types.h>
 #include <sys/stat.h>
 
 #include <errno.h>
 #include <fcntl.h>
+#include <inttypes.h>
 #include <string.h>
 #include <unistd.h>
 
-#include "conf.h"
 #include "xmalloc.h"
 #include "error.h"
 #include "symon.h"
@@ -54,6 +54,7 @@
 static void *if_buf = NULL;
 static int if_size = 0;
 static int if_maxsize = 0;
+static int if_fd = -1;
 struct if_device_stats
 {
     u_int64_t rx_packets;             /* total packets received       */
@@ -86,22 +87,22 @@ init_if(struct stream *st)
         if_buf = xmalloc(if_maxsize);
     }
 
+    snprintf(st->parg.ifname, sizeof(st->parg.ifname), "%s:", st->arg);
+
+    if ((if_fd = open("/proc/net/dev", O_RDONLY)) < 0)
+        warning("cannot access /proc/net/dev: %.200s", strerror(errno));
+
     info("started module if(%.200s)", st->arg);
 }
 
 void
-gets_if()
+gets_if(void)
 {
-    int fd;
-
-    if ((fd = open("/proc/net/dev", O_RDONLY)) < 0) {
-        warning("cannot access /proc/net/dev: %.200s", strerror(errno));
-        return;
-    }
+    if (lseek(if_fd, 0, SEEK_SET) != 0)
+        fatal("/proc/net/dev seek error: %.200s", strerror(errno));
 
     bzero(if_buf, if_maxsize);
-    if_size = read(fd, if_buf, if_maxsize);
-    close(fd);
+    if_size = read(if_fd, if_buf, if_maxsize);
 
     if (if_size == if_maxsize) {
         /* buffer is too small to hold all interface data */
@@ -130,18 +131,21 @@ get_if(char *symon_buf, int maxlen, struct stream *st)
         return 0;
     }
 
-    if ((line = strstr(if_buf, st->arg)) == NULL) {
+    if ((line = strstr(if_buf, st->parg.ifname)) == NULL) {
         warning("could not find interface %s", st->arg);
         return 0;
     }
 
-    line += strlen(st->arg);
+    line += strlen(st->parg.ifname);
     bzero(&stats, sizeof(struct if_device_stats));
 
     /* Inter-|   Receive                                                |  Transmit
      *  face |bytes    packets errs drop fifo frame compressed multicast|bytes    packets errs drop fifo colls carrier compressed
      */
-    if (16 > sscanf(line, ":%Lu %Lu %Lu %Lu %Lu %Lu %Lu %Lu %Lu %Lu %Lu %Lu %Lu %Lu %Lu %Lu\n",
+    if (16 > sscanf(line, "%" SCNu64 " %" SCNu64 " %" SCNu64 " %" SCNu64 " %" SCNu64 " %"
+                               SCNu64 " %" SCNu64 " %" SCNu64 " %"
+                               SCNu64 " %" SCNu64 " %" SCNu64 " %" SCNu64 " %" SCNu64 " %"
+                               SCNu64 " %" SCNu64 " %" SCNu64 "\n",
                     &stats.rx_bytes, &stats.rx_packets, &stats.rx_errors, &stats.rx_dropped, &stats.rx_fifo_errors,
                     &stats.rx_frame_errors, &stats.rx_compressed, &stats.multicast,
                     &stats.tx_bytes, &stats.tx_packets, &stats.tx_errors, &stats.tx_dropped, &stats.tx_fifo_errors,
