@@ -1,5 +1,3 @@
-/* $Id: sm_mem.c,v 1.7 2008/01/30 14:29:31 dijkstra Exp $ */
-
 /*
  * Copyright (c) 2005-2007 Harm Schotanus
  * All rights reserved.
@@ -36,13 +34,16 @@
  * real active : real total : free : [swap used : swap total]
  */
 
-#include <stdlib.h>
-#include <string.h>
+#include "conf.h"
+
 #include <errno.h>
 #include <fcntl.h>
+#include <inttypes.h>
+#include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
+
 #include "error.h"
-#include "conf.h"
 #include "symon.h"
 #include "xmalloc.h"
 
@@ -53,6 +54,7 @@ static void *me_buf = NULL;
 static u_int64_t me_size = 0;
 static u_int64_t me_maxsize = 0;
 static u_int64_t me_stats[5];
+static int me_fd = -1;
 
 void
 init_mem(struct stream *st)
@@ -62,20 +64,31 @@ init_mem(struct stream *st)
         me_buf = xmalloc(me_maxsize);
     }
 
+    if ((me_fd = open("/proc/meminfo", O_RDONLY)) < 0)
+        warning("cannot access /proc/meminfo: %.200s", strerror(errno));
+
     info("started module mem(%.200s)", st->arg);
 }
 
 void
-gets_mem()
+gets_mem(void)
 {
-   int fd;
-   if ((fd = open("/proc/meminfo", O_RDONLY)) < 0) {
-        warning("cannot access /proc/meminfo: %.200s", strerror(errno));
-   }
+   ssize_t r;
+
+   if (lseek(me_fd, 0, SEEK_SET) != 0)
+        fatal("/proc/meminfo seek error: %.200s", strerror(errno));
 
    bzero(me_buf, me_maxsize);
-   me_size = read(fd, me_buf, me_maxsize);
-   close(fd);
+   r = read(me_fd, me_buf, me_maxsize);
+   if (r < 0) {
+       if (r != -1)
+           fatal("read returned %d", r);
+
+       warning("could not read if statistics from /proc/meminfo: %.200s", strerror(errno));
+       return;
+   }
+
+   me_size = r;
 
    if (me_size == me_maxsize) {
         /* buffer is too small to hold all memory data */
@@ -88,10 +101,6 @@ gets_mem()
         gets_mem();
         return;
     }
-
-   if (me_size == -1) {
-       warning("could not read if statistics from /proc/meminfo: %.200s", strerror(errno));
-   }
 }
 
 u_int64_t
@@ -110,7 +119,7 @@ mem_getitem(char *name)
     }
 
     line += strlen(name);
-    if (1 < sscanf(line, ": %llu Kb", &stat)) {
+    if (1 < sscanf(line, ": %" SCNu64 " Kb", &stat)) {
         warning("could not parse memory statistics");
         return 0;
     } else {
@@ -123,7 +132,7 @@ get_mem(char *symon_buf, int maxlen, struct stream *st)
 {
     me_stats[0] = ktob(mem_getitem("Active"));
     me_stats[1] = ktob(mem_getitem("MemTotal"));
-    me_stats[2] = ktob(mem_getitem("MemFree"));
+    me_stats[2] = ktob(mem_getitem("MemAvailable"));
     me_stats[1] -= me_stats[2];
     me_stats[3] = ktob(mem_getitem("SwapFree"));
     me_stats[4] = ktob(mem_getitem("SwapTotal"));
