@@ -1,5 +1,3 @@
-/* $Id: sm_if.c,v 1.6 2007/12/11 14:17:59 dijkstra Exp $ */
-
 /*
  * Copyright (c) 2004-2007      Matthew Gream
  * All rights reserved.
@@ -67,13 +65,13 @@ init_if(struct stream *st)
         }
     }
 
-    strncpy(st->parg.ifr.ifdr_name, st->arg, sizeof(st->parg.ifr.ifdr_name));
+    strncpy(st->parg.ifr.ifdr_name, st->arg, (sizeof(st->parg.ifr.ifdr_name) - 1));
 
     info("started module if(%.200s)", st->arg);
 }
 
 void
-gets_if()
+gets_if(void)
 {
     /* EMPTY */
 }
