@@ -1,5 +1,3 @@
-/* $Id: sm_pfq.c,v 1.5 2007/07/09 12:32:16 dijkstra Exp $ */
-
 /*
  * Copyright (c) 2005 J. Martin Petersen
  * All rights reserved.
@@ -64,7 +62,7 @@
 
 #ifndef HAS_PFVAR_H
 void
-privinit_pfq()
+privinit_pfq(void)
 {
     fatal("pf support not available");
 }
@@ -74,7 +72,7 @@ init_pfq(struct stream *st)
     fatal("pf support not available");
 }
 void
-gets_pfq()
+gets_pfq(void)
 {
     fatal("pf support not available");
 }
@@ -118,7 +116,7 @@ static int pfq_max = 0;
 int pfq_dev = -1;
 
 void
-privinit_pfq()
+privinit_pfq(void)
 {
     if ((pfq_dev = open("/dev/pf", O_RDONLY)) == -1) {
         warning("pfq: could not open \"/dev/pf\", %.200s", strerror(errno));
@@ -136,13 +134,13 @@ init_pfq(struct stream *st)
 }
 
 void
-gets_pfq()
+gets_pfq(void)
 {
     struct pfioc_altq qs;
     struct pfioc_qstats stats;
     union class_stats q;
-    unsigned int nqs;
-    unsigned int i;
+    int nqs;
+    int i;
 
     bzero(&qs, sizeof(qs));
     bzero(&stats, sizeof(stats));
@@ -227,7 +225,7 @@ gets_pfq()
 int
 get_pfq(char *symon_buf, int maxlen, struct stream *st)
 {
-    unsigned int i;
+    int i;
 
     for (i = 0; i < pfq_cur; i++) {
         if (strncmp(pfq_stats[i].qname, st->arg, sizeof(pfq_stats[0].qname)) == 0) {
