@@ -1,11 +1,5 @@
-/* $Id: sm_cpu.c,v 1.26 2007/07/09 12:54:18 dijkstra Exp $ */
-
-/* The author of this code is Willem Dijkstra (wpd@xs4all.nl).
- *
- * The percentages function was written by William LeFebvre and is part
- * of the 'top' utility. His copyright statement is below.
- *
- * Copyright (c) 2001-2007 Willem Dijkstra
+/*
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,17 +28,6 @@
  *
  */
 
-/*
- *  Top users/processes display for Unix
- *  Version 3
- *
- *  This program may be freely redistributed,
- *  but this entire comment MUST remain intact.
- *
- *  Copyright (c) 1984, 1989, William LeFebvre, Rice University
- *  Copyright (c) 1989, 1990, 1992, William LeFebvre, Northwestern University
- */
-
 /*
  * Get current cpu statistics in percentages (total of all counts = 100.0)
  * and returns them in symon_buf as
@@ -56,7 +39,6 @@
 
 #include "conf.h"
 
-#include <sys/dkstat.h>
 #include <sys/param.h>
 #include <sys/sysctl.h>
 
@@ -66,65 +48,23 @@
 #include <string.h>
 
 #include "error.h"
+#include "percentages.h"
 #include "symon.h"
-/*
- *  percentages(cnt, out, new, old, diffs) - calculate percentage change
- *      between array "old" and "new", putting the percentages i "out".
- *      "cnt" is size of each array and "diffs" is used for scratch space.
- *      The array "old" is updated on each call.
- *      The routine assumes modulo arithmetic.  This function is especially
- *      useful on BSD mchines for calculating cpu state percentages.
- */
-int
-percentages(int cnt, int64_t *out, int64_t *new, int64_t *old, int64_t *diffs)
-{
-    int64_t change, total_change, *dp, half_total;
-    int i;
-
-    /* initialization */
-    total_change = 0;
-    dp = diffs;
-
-    /* calculate changes for each state and the overall change */
-    for (i = 0; i < cnt; i++) {
-        if ((change = *new - *old) < 0) {
-            /* this only happens when the counter wraps */
-            change = (QUAD_MAX - *old) + *new;
-        }
-        total_change += (*dp++ = change);
-        *old++ = *new++;
-    }
-
-    /* avoid divide by zero potential */
-    if (total_change == 0)
-        total_change = 1;
-
-    /* calculate percentages based on overall change, rounding up */
-    half_total = total_change / 2l;
-    for (i = 0; i < cnt; i++)
-        *out++ = ((*diffs++ * 1000 + half_total) / total_change);
-
-    /* return the total in case the caller wants to use it */
-    return (total_change);
-}
 
 void
 init_cpu(struct stream *st)
 {
     char buf[SYMON_MAX_OBJSIZE];
-#ifdef HAS_KERN_CPTIME2
     const char *errstr;
     int mib[2] = {CTL_HW, HW_NCPU};
     int ncpu;
     long num;
     size_t size = sizeof(ncpu);
-#endif
 
     st->parg.cp.mib[0] = CTL_KERN;
     st->parg.cp.mib[1] = KERN_CPTIME;
     st->parg.cp.miblen = 2;
 
-#ifdef HAS_KERN_CPTIME2
     if (sysctl(mib, 2, &ncpu, &size, NULL, 0) == -1) {
         warning("could not determine number of cpus: %.200s", strerror(errno));
         ncpu = 1;
@@ -144,7 +84,6 @@ init_cpu(struct stream *st)
             fatal("cpu(%d) is not present", st->parg.cp.mib[2]);
         }
     }
-#endif
 
     /* Call get_cpu once to fill the cp_old structure */
     get_cpu(buf, sizeof(buf), st);
@@ -153,7 +92,7 @@ init_cpu(struct stream *st)
 }
 
 void
-gets_cpu()
+gets_cpu(void)
 {
     /* EMPTY */
 }
@@ -161,7 +100,7 @@ gets_cpu()
 int
 get_cpu(char *symon_buf, int maxlen, struct stream *st)
 {
-    int i, total;
+    int i;
     size_t len;
 
     len = sizeof(st->parg.cp.time2);
@@ -180,7 +119,7 @@ get_cpu(char *symon_buf, int maxlen, struct stream *st)
     }
 
     /* convert cp_time counts to percentages */
-    total = percentages(CPUSTATES, st->parg.cp.states, st->parg.cp.time2, st->parg.cp.old, st->parg.cp.diff);
+    percentages(CPUSTATES, st->parg.cp.states, st->parg.cp.time2, st->parg.cp.old, st->parg.cp.diff);
 
     return snpack(symon_buf, maxlen, st->arg, MT_CPU,
                   (double) (st->parg.cp.states[CP_USER] / 10.0),
