@@ -1,7 +1,5 @@
-/* $Id: sm_mem.c,v 1.23 2008/02/20 08:17:25 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2008 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,7 +37,9 @@
 #include <sys/param.h>
 #include <sys/sysctl.h>
 #include <sys/swap.h>
+#include <sys/vmmeter.h>
 
+#include <errno.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -98,9 +98,10 @@ init_mem(struct stream *st)
 }
 
 void
-gets_mem()
+gets_mem(void)
 {
-    int i, rnswap;
+    size_t i;
+    int rnswap;
 
     if (sysctl(me_vm_mib, 2, &me_vmtotal, &me_vmsize, NULL, 0) < 0) {
         warning("%s:%d: sysctl failed", __FILE__, __LINE__);
@@ -117,15 +118,23 @@ gets_mem()
         /* A swap device may have been added; increase and retry */
         init_mem(NULL);
         rnswap = swapctl(SWAP_STATS, me_swdev, me_nswap);
+        if (rnswap == -1) {
+            warning("%s:%d: swapctl failed %s", __FILE__, __LINE__,
+                strerror(errno));
+            return;
+        }
     }
+    if (rnswap < 0)
+        fatal("unexpected return code from swapctl");
 
+    i = rnswap;
     me_stats[3] = me_stats[4] = 0;
-    if (rnswap == me_nswap) {   /* Read swap successfully */
+    if (i == me_nswap) {   /* Read swap successfully */
         /* Total things up */
         for (i = 0; i < me_nswap; i++) {
             if (me_swdev[i].se_flags & SWF_ENABLE) {
-                me_stats[3] += (me_swdev[i].se_inuse * DEV_BSIZE);
-                me_stats[4] += (me_swdev[i].se_nblks * DEV_BSIZE);
+                me_stats[3] += ((u_int64_t)me_swdev[i].se_inuse * DEV_BSIZE);
+                me_stats[4] += ((u_int64_t)me_swdev[i].se_nblks * DEV_BSIZE);
             }
         }
     }
