@@ -1,5 +1,3 @@
-/* $Id: sm_cpuiow.c,v 1.1 2008/01/30 12:06:50 dijkstra Exp $ */
-
 #include <stdlib.h>
 
 #include "sylimits.h"
@@ -12,7 +10,7 @@ init_cpuiow(struct stream *st)
     fatal("cpuiow module not available");
 }
 void
-gets_cpuiow()
+gets_cpuiow(void)
 {
     fatal("cpuiow module not available");
 }
