@@ -1,5 +1,3 @@
-/* $Id: sm_df.c,v 1.2 2005/10/18 19:58:12 dijkstra Exp $ */
-
 #include <stdlib.h>
 
 #include "sylimits.h"
@@ -12,7 +10,7 @@ init_df(struct stream *st)
     fatal("df module not available");
 }
 void
-gets_df()
+gets_df(void)
 {
     fatal("df module not available");
 }
