@@ -1,5 +1,3 @@
-/* $Id: sm_if.c,v 1.3 2005/10/18 19:58:12 dijkstra Exp $ */
-
 #include <stdlib.h>
 
 #include "sylimits.h"
@@ -12,7 +10,7 @@ init_if(struct stream *st)
     fatal("if module not available");
 }
 void
-gets_if()
+gets_if(void)
 {
     fatal("if module not available");
 }
