@@ -1,5 +1,3 @@
-/* $Id: sm_pfq.c,v 1.2 2005/10/18 19:58:12 dijkstra Exp $ */
-
 #include <stdlib.h>
 
 #include "sylimits.h"
@@ -7,7 +5,7 @@
 #include "error.h"
 
 void
-privinit_pfq()
+privinit_pfq(void)
 {
     fatal("pfq module not available");
 }
@@ -17,7 +15,7 @@ init_pfq(struct stream *st)
     fatal("pfq module not available");
 }
 void
-gets_pfq()
+gets_pfq(void)
 {
     fatal("pfq module not available");
 }
