@@ -1,5 +1,3 @@
-/* $Id: sm_proc.c,v 1.3 2005/10/19 20:06:07 dijkstra Exp $ */
-
 #include <stdlib.h>
 
 #include "sylimits.h"
@@ -13,13 +11,13 @@ init_proc(struct stream *st)
 }
 
 void
-gets_proc()
+gets_proc(void)
 {
     fatal("proc module not available");
 }
 
 void
-privinit_proc()
+privinit_proc(void)
 {
     fatal("proc module not available");
 }
