@@ -34,8 +34,6 @@
 
 #include "data.h"
 
-__BEGIN_DECLS
 int read_config_file(struct muxlist *, const char *, int);
-__END_DECLS
 
 #endif                          /* _SYMUX_READCONF_H */
